@@ -14,7 +14,7 @@ APPLE_MFR_ID = 76
 IBEACON_FIRST_BYTE = 0x02
 IBEACON_SECOND_BYTE = 0x15
 
-__version__ = "0.6.1"
+__version__ = "0.6.2"
 
 __all__ = [
     "parse",
@@ -82,6 +82,7 @@ def calculate_distance_meters(power: int, rssi: int) -> float | None:
     if rssi == 0:
         return None
     if (ratio := rssi * 1.0 / power) < 1.0:
-        return pow(ratio, 10)
-    distance = cast(float, 0.89976 * pow(ratio, 7.7095) + 0.111)
+        distance = pow(ratio, 10)
+    else:
+        distance = cast(float, 0.89976 * pow(ratio, 7.7095) + 0.111)
     return distance if distance < 1000 else None
